==> jc-1.4.0.tar.gz: gnu/xml/transform/ChooseNode.h <==
// final class gnu.xml.transform.ChooseNode

// class file dependencies
// @dep_class 484837d39a14ee46 gnu_xml_transform_ChooseNode
// @dep_class ef8509869908c7a6 gnu_xml_transform_TemplateNode
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_transform_TemplateNode

#include "gnu/xml/transform/TemplateNode.h"

#ifndef _JC_gnu_xml_transform_ChooseNode_H_
#define _JC_gnu_xml_transform_ChooseNode_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_transform_TemplateNode$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_namespace_QName$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_ChooseNode$sub_refs	_jc_gnu_xml_transform_ChooseNode$sub_refs;
typedef struct _jc_gnu_xml_transform_ChooseNode$sub_nonrefs	_jc_gnu_xml_transform_ChooseNode$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_ChooseNode$refs	_jc_gnu_xml_transform_ChooseNode$refs;
typedef struct _jc_gnu_xml_transform_ChooseNode$nonrefs	_jc_gnu_xml_transform_ChooseNode$nonrefs;
typedef struct _jc_gnu_xml_transform_ChooseNode$object	_jc_gnu_xml_transform_ChooseNode$object;

typedef const struct _jc_gnu_xml_transform_ChooseNode$vmethods	_jc_gnu_xml_transform_ChooseNode$vmethods;
typedef const struct _jc_gnu_xml_transform_ChooseNode$vtable	_jc_gnu_xml_transform_ChooseNode$vtable;
typedef const struct _jc_gnu_xml_transform_ChooseNode$vtype	_jc_gnu_xml_transform_ChooseNode$vtype;

// Constructors
extern void _jc_gnu_xml_transform_ChooseNode$method$_init$397d752fa8327fc4(_jc_env *, struct _jc_gnu_xml_transform_ChooseNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *);

// Virtual methods
extern struct _jc_gnu_xml_transform_TemplateNode$object *_jc_gnu_xml_transform_ChooseNode$method$clone$b8a038f4254cb648(_jc_env *, struct _jc_gnu_xml_transform_ChooseNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);
extern void _jc_gnu_xml_transform_ChooseNode$method$doApply$85a30cd55d4e7167(_jc_env *, struct _jc_gnu_xml_transform_ChooseNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_transform_ChooseNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_transform_ChooseNode$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_ChooseNode$method_info$clone$b8a038f4254cb648;
extern _jc_method _jc_gnu_xml_transform_ChooseNode$method_info$doApply$85a30cd55d4e7167;
extern _jc_method _jc_gnu_xml_transform_ChooseNode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_transform_ChooseNode$vmethods {
	struct _jc_gnu_xml_transform_TemplateNode$object	*(*clone$b8a038f4254cb648)(_jc_env *, struct _jc_gnu_xml_transform_ChooseNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);
	void	(*doApply$85a30cd55d4e7167)(_jc_env *, struct _jc_gnu_xml_transform_ChooseNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_transform_ChooseNode$object *);
};

// Vtable
struct _jc_gnu_xml_transform_ChooseNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_TemplateNode$vmethods	gnu_xml_transform_TemplateNode;
	_jc_gnu_xml_transform_ChooseNode$vmethods	gnu_xml_transform_ChooseNode;
};

// Vtype
struct _jc_gnu_xml_transform_ChooseNode$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_ChooseNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_ChooseNode$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_ChooseNode$refs {
    _jc_gnu_xml_transform_ChooseNode$sub_refs	gnu_xml_transform_ChooseNode;
    _jc_gnu_xml_transform_TemplateNode$sub_refs	gnu_xml_transform_TemplateNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_ChooseNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_ChooseNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_TemplateNode$sub_nonrefs	gnu_xml_transform_TemplateNode;
    _jc_gnu_xml_transform_ChooseNode$sub_nonrefs	gnu_xml_transform_ChooseNode;
};

// Object instance structure
struct _jc_gnu_xml_transform_ChooseNode$object {
	_jc_gnu_xml_transform_ChooseNode$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_ChooseNode$vtype	*vtype;
	_jc_gnu_xml_transform_ChooseNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_ChooseNode$vtype _jc_gnu_xml_transform_ChooseNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_ChooseNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_ChooseNode$class_object;

#endif	/* _JC_gnu_xml_transform_ChooseNode_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/transform/ChooseNode.h <==
// final class gnu.xml.transform.ChooseNode

// class file dependencies
// @dep_class 484837d39a14ee46 gnu_xml_transform_ChooseNode
// @dep_class ef8509869908c7a6 gnu_xml_transform_TemplateNode
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_transform_TemplateNode

#include "gnu/xml/transform/TemplateNode.h"

#ifndef _JC_gnu_xml_transform_ChooseNode_H_
#define _JC_gnu_xml_transform_ChooseNode_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_transform_TemplateNode$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_namespace_QName$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_ChooseNode$sub_refs	_jc_gnu_xml_transform_ChooseNode$sub_refs;
typedef struct _jc_gnu_xml_transform_ChooseNode$sub_nonrefs	_jc_gnu_xml_transform_ChooseNode$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_ChooseNode$refs	_jc_gnu_xml_transform_ChooseNode$refs;
typedef struct _jc_gnu_xml_transform_ChooseNode$nonrefs	_jc_gnu_xml_transform_ChooseNode$nonrefs;
typedef struct _jc_gnu_xml_transform_ChooseNode$object	_jc_gnu_xml_transform_ChooseNode$object;

typedef const struct _jc_gnu_xml_transform_ChooseNode$vmethods	_jc_gnu_xml_transform_ChooseNode$vmethods;
typedef const struct _jc_gnu_xml_transform_ChooseNode$vtable	_jc_gnu_xml_transform_ChooseNode$vtable;
typedef const struct _jc_gnu_xml_transform_ChooseNode$vtype	_jc_gnu_xml_transform_ChooseNode$vtype;

// Constructors
extern void _jc_gnu_xml_transform_ChooseNode$method$_init$397d752fa8327fc4(_jc_env *, struct _jc_gnu_xml_transform_ChooseNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_transform_TemplateNode$object *_jc_gnu_xml_transform_ChooseNode$method$clone$b8a038f4254cb648(_jc_env *, struct _jc_gnu_xml_transform_ChooseNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_transform_ChooseNode$method$doApply$85a30cd55d4e7167(_jc_env *, struct _jc_gnu_xml_transform_ChooseNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_transform_ChooseNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_transform_ChooseNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_ChooseNode$method_info$clone$b8a038f4254cb648;
extern _jc_method _jc_gnu_xml_transform_ChooseNode$method_info$doApply$85a30cd55d4e7167;
extern _jc_method _jc_gnu_xml_transform_ChooseNode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_transform_ChooseNode$vmethods {
	struct _jc_gnu_xml_transform_TemplateNode$object	*(*clone$b8a038f4254cb648)(_jc_env *, struct _jc_gnu_xml_transform_ChooseNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;
	void	(*doApply$85a30cd55d4e7167)(_jc_env *, struct _jc_gnu_xml_transform_ChooseNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_transform_ChooseNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_transform_ChooseNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_TemplateNode$vmethods	gnu_xml_transform_TemplateNode;
	_jc_gnu_xml_transform_ChooseNode$vmethods	gnu_xml_transform_ChooseNode;
};

// Vtype
struct _jc_gnu_xml_transform_ChooseNode$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_ChooseNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_ChooseNode$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_ChooseNode$refs {
    _jc_gnu_xml_transform_ChooseNode$sub_refs	gnu_xml_transform_ChooseNode;
    _jc_gnu_xml_transform_TemplateNode$sub_refs	gnu_xml_transform_TemplateNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_ChooseNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_ChooseNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_TemplateNode$sub_nonrefs	gnu_xml_transform_TemplateNode;
    _jc_gnu_xml_transform_ChooseNode$sub_nonrefs	gnu_xml_transform_ChooseNode;
};

// Object instance structure
struct _jc_gnu_xml_transform_ChooseNode$object {
	_jc_gnu_xml_transform_ChooseNode$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_ChooseNode$vtype	*vtype;
	_jc_gnu_xml_transform_ChooseNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_ChooseNode$vtype _jc_gnu_xml_transform_ChooseNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_ChooseNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_ChooseNode$class_object;

#endif	/* _JC_gnu_xml_transform_ChooseNode_H_ */
